import React, { useRef } from 'react';
import { requireNativeComponent, findNodeHandle, type StyleProp, type ViewStyle } from 'react-native';

type MyViewProps = {
  style?: StyleProp<ViewStyle>;
  onViewCreated?: (viewId: number) => void;
};

const MyViewManagerView = requireNativeComponent<any>('MyViewManager'); // Use 'any' temporarily or adjust to the correct props type

const MyViewManager = (props: MyViewProps) => {
  const { onViewCreated } = props;
  const viewRef = useRef<any>(null); // Use 'any' for ref temporarily or adjust to the correct type

  React.useEffect(() => {
    if (onViewCreated) {
      const viewId = findNodeHandle(viewRef.current);
      if (viewId) {
        onViewCreated(viewId);
      }
    }
  }, [onViewCreated]);

  return <MyViewManagerView {...props} ref={viewRef} />; // Spread props to pass style and other props correctly
};

export default MyViewManager;
