import React, { useRef } from 'react';
import { requireNativeComponent, findNodeHandle, type StyleProp, type ViewStyle } from 'react-native';

type MyViewProps = {
  style?: StyleProp<ViewStyle>; // Adjusted to use StyleProp<ViewStyle>
  onViewCreated?: (viewId: number | null) => void;
};

const MyViewManagerView = requireNativeComponent<any>('MyViewManager'); // Temporarily use 'any' for props type

const MyViewManager = (props: MyViewProps) => {
  const { onViewCreated } = props;
  const viewRef = useRef<any>(null); // Temporarily use 'any' for ref type

  React.useEffect(() => {
    if (onViewCreated) {
      const viewId = findNodeHandle(viewRef.current);
      onViewCreated(viewId);
    }
  }, [onViewCreated]);

  return <MyViewManagerView {...props} ref={viewRef} />; // Spread props to pass style and other props correctly
};

export { MyViewManager };
