import React, { useEffect, useRef } from 'react';
import {
  requireNativeComponent,
  UIManager,
  findNodeHandle,
  PixelRatio,
  type ViewStyle,
  Platform,
} from 'react-native';

const LINKING_ERROR =
  `The package 'react-native-android-view' doesn't seem to be linked. Make sure: \n\n` +
  Platform.select({ ios: "- You have run 'pod install'\n", default: '' }) +
  '- You rebuilt the app after installing the package\n' +
  '- You are not using Expo Go\n';

type AndroidViewProps = {
  color: string;
  style: ViewStyle;
  viewId: number;
};

const ComponentName = 'MyViewManager';

const AndroidViewComponent =
  UIManager.getViewManagerConfig(ComponentName) != null
    ? requireNativeComponent<AndroidViewProps>(ComponentName)
    : () => {
        throw new Error(LINKING_ERROR);
      };

const createFragment = (viewId: number) => {
  const viewManagerConfig = UIManager.getViewManagerConfig(ComponentName);
  if (viewManagerConfig && viewManagerConfig.Commands) {
    const commandCreate = viewManagerConfig.Commands.create;
    if (commandCreate !== undefined) {
      UIManager.dispatchViewManagerCommand(
        viewId,
        commandCreate.toString(),
        [viewId]
      );
    } else {
      console.error(`'create' command is not defined in ${ComponentName} Commands`);
    }
  } else {
    console.error(`Failed to get view manager config for ${ComponentName}`);
  }
};

const AndroidView: React.FC<AndroidViewProps> = ({ viewId, style, ...props }) => {
  const ref = useRef(null);

  useEffect(() => {
    const resolvedViewId = viewId || findNodeHandle(ref.current);
    if (resolvedViewId) {
      createFragment(resolvedViewId);
    } else {
      console.error('Failed to resolve view ID');
    }
  }, [viewId]);

  return (
    <AndroidViewComponent
      style={{
        height: PixelRatio.getPixelSizeForLayoutSize(200),
        width: PixelRatio.getPixelSizeForLayoutSize(200),
        ...style,
      }}
      // ref={ref}
      viewId={viewId}
      {...props}
    />
  );
};

export default AndroidView;
